Struct googapis::google::cloud::dialogflow::v2::AnalyzeContentResponse [−][src]
pub struct AnalyzeContentResponse {
pub reply_text: String,
pub reply_audio: Option<OutputAudio>,
pub automated_agent_reply: Option<AutomatedAgentReply>,
pub message: Option<Message>,
pub human_agent_suggestion_results: Vec<SuggestionResult>,
pub end_user_suggestion_results: Vec<SuggestionResult>,
pub dtmf_parameters: Option<DtmfParameters>,
}Expand description
The response message for [Participants.AnalyzeContent][google.cloud.dialogflow.v2.Participants.AnalyzeContent].
Fields
reply_text: StringThe output text content. This field is set if the automated agent responded with text to show to the user.
reply_audio: Option<OutputAudio>The audio data bytes encoded as specified in the request. This field is set if:
reply_audio_configwas specified in the request, or- The automated agent responded with audio to play to the user. In such
case,
reply_audio.configcontains settings used to synthesize the speech.
In some scenarios, multiple output audio fields may be present in the response structure. In these cases, only the top-most-level audio output has content.
automated_agent_reply: Option<AutomatedAgentReply>Only set if a Dialogflow automated agent has responded. Note that: [AutomatedAgentReply.detect_intent_response.output_audio][] and [AutomatedAgentReply.detect_intent_response.output_audio_config][] are always empty, use [reply_audio][google.cloud.dialogflow.v2.AnalyzeContentResponse.reply_audio] instead.
message: Option<Message>Message analyzed by CCAI.
human_agent_suggestion_results: Vec<SuggestionResult>The suggestions for most recent human agent. The order is the same as [HumanAgentAssistantConfig.SuggestionConfig.feature_configs][google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.feature_configs] of [HumanAgentAssistantConfig.human_agent_suggestion_config][google.cloud.dialogflow.v2.HumanAgentAssistantConfig.human_agent_suggestion_config].
end_user_suggestion_results: Vec<SuggestionResult>The suggestions for end user. The order is the same as [HumanAgentAssistantConfig.SuggestionConfig.feature_configs][google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.feature_configs] of [HumanAgentAssistantConfig.end_user_suggestion_config][google.cloud.dialogflow.v2.HumanAgentAssistantConfig.end_user_suggestion_config].
dtmf_parameters: Option<DtmfParameters>Indicates the parameters of DTMF.